@@ -17,7 +17,8 @@ from .exchange_calendar_ose import OSEExchangeCalendar
 from .exchange_calendar_six import SIXExchangeCalendar
 from .exchange_calendar_sse import SSEExchangeCalendar
 from .exchange_calendar_tsx import TSXExchangeCalendar
-from .exchange_calendar_xbom import XBOMExchangeCalendar
+from .exchange_calendar_bse import BSEExchangeCalendar
+from .exchange_calendar_tase import TASEExchangeCalendar
 from .trading_calendars_mirror import *
 
 
